measuretools.color_nonbinary_measures_in_expr
=============================================

.. autofunction:: abjad.tools.measuretools.color_nonbinary_measures_in_expr.color_nonbinary_measures_in_expr
